==> nextcloud-app-deck-1%3A1.13.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ast.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Tarxeteru",
    "Upcoming cards" : "Tarxetes próximes",
    "Load more" : "Cargar más",
    "Personal" : "Personal",
    "Deck board" : "Mesa de tarxetes",
    "%s on %s" : "%s n %s",
    "Action needed" : "Aición necesaria",
    "copy" : "copia",
    "To do" : "Xera pendiente",
    "Done" : "Fecho",
    "Example Task 3" : "Xera d'exemplu 3",
    "Example Task 2" : "Xera d'exemplu 2",
    "Example Task 1" : "Xera d'exemplu 1",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu supera la direutiva «upload_max_filesize» del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu supera la direutiva «MAX_FILE_SIZE» que s'especificó nel formulariu HTML",
    "No file was uploaded" : "Nun se xubió nengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "Nun se pudo escribir el ficheru nel discu",
    "A PHP extension stopped the file upload" : "Una estensión PHP paró la xuba de ficheros",
    "No file uploaded or file size exceeds maximum of %s" : "Nun se xubió nengún ficheru o'l tamañu del ficheru supera'l máximu de %s",
    "Invalid date, date format must be YYYY-MM-DD" : "La data ye inválida, el so formatu ha ser AAAA-MM-DD",
    "Move card" : "Mover la tarxeta",
    "Cancel" : "Encaboxar",
    "File already exists" : "El ficheru yá esiste",
    "Drop your files to upload" : "Suelta los ficheros pa xubilos",
    "Add card" : "Amestar una tarxeta",
    "Archived cards" : "Tarxetes archivaes",
    "Add list" : "Amestar una llista",
    "List name" : "Nome de la llista",
    "Open" : "Abrir",
    "Completed" : "Completáu",
    "Next 24 hours" : "Les próximes 24 hores",
    "Next 7 days" : "Los próximos 7 díes",
    "Next 30 days" : "Los próximos 30 díes",
    "Open details" : "Abrir los detalles",
    "Details" : "Detalles",
    "Sharing" : "Comparticiñon",
    "Tags" : "Etiquetes",
    "Deleted items" : "Elementos desaniciaos",
    "Activity" : "Actividá",
    "Deleted lists" : "Llistes desaniciaes",
    "Undo" : "Desfacer",
    "Deleted cards" : "Tarxetes desaniciaes",
    "(Group)" : "(Grupu)",
    "(Team)" : "(Equipu)",
    "Can edit" : "Pue editar",
    "Owner" : "Propietariu",
    "Delete" : "Desaniciar",
    "Transfer" : "Tresferir",
    "Edit list title" : "Editar el títulu de la llista",
    "Archive all cards" : "Archivar toles carpetes",
    "Unarchive all cards" : "Desarchivar toles tarxetes",
    "Delete list" : "Desaniciar la llista",
    "Archive all cards in this list" : "Archivar toles tarxetes d'esta llista",
    "Unarchive all cards in this list" : "Desarchivar toles tarxetes d'esta llista",
    "Add a new card" : "Amestar una tarxeta nueva",
    "Card name" : "Nome de la tarxeta",
    "List deleted" : "Desanicióse la llista",
    "Edit" : "Editar",
    "Add a new tag" : "Amestar una etiqueta nueva",
    "Members" : "Miembros",
    "Show in Files" : "Amosar en Ficheros",
    "Download" : "Baxar",
    "Invalid path selected" : "Seleicionóse un camín inválidu",
    "Comments" : "Comentarios",
    "Modified" : "Modificóse",
    "The title cannot be empty." : "El títulu nun pue tar baleru",
    "No comments yet. Begin the discussion!" : "Nun hai nengún comentariu. ¡Comienza'l discutiniu!",
    "Failed to load comments" : "Nun se puen cargar los comentarios",
    "Save" : "Guardar",
    "The comment cannot be empty." : "El comentariu nun pue tar baleru.",
    "In reply to" : "En rempuesta a",
    "Reply" : "Responder",
    "Update" : "Anovar",
    "Created:" : "Creóse'l",
    "Description" : "Descripción",
    "(Unsaved)" : "(ensin guardar)",
    "(Saving…)" : "(Guardando…)",
    "Formatting help" : "Ayuda del formatu",
    "Edit description" : "Editar la descripción",
    "View description" : "Ver la descripción",
    "Mark as done" : "Marcar como fecha",
    "Archive card" : "Archivar la tarxeta",
    "(group)" : "(grupu)",
    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
    "Delete card" : "Desaniciar la tarxeta",
    "seconds ago" : "hai segundos",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Keyboard shortcut" : "Atayos del tecláu",
    "Action" : "Aición",
    "Ctrl" : "Ctrl",
    "Search" : "Guetar",
    "Shared with you" : "Compartióse contigo",
    "All cards" : "Toles tarxetes",
    "No notifications" : "Nun hai nengún avisu",
    "No reminder" : "Nun hai nengún recordatoriu",
    "An error occurred" : "Prodúxose un error",
    "Today" : "Güei",
    "Tomorrow" : "Mañana",
    "No results found" : "Nun s'atopó nengún resultáu",
    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
    "Close" : "Zarrar",
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "Message from {author} in {conversationName}" : "Mensaxe de {author} en {conversationName}",
    "Error creating the share" : "Hebo un error al crear la compartición",
    "Share" : "Compartir",
    "Timeline" : "Llinia de tiempu",
    "Next week" : "La selmana que vien",
    "Next month" : "Mes siguiente",
    "Not completed" : "Nun se completó"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.14.2-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ast.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Tarxeteru",
    "Upcoming cards" : "Tarxetes próximes",
    "Load more" : "Cargar más",
    "Personal" : "Personal",
    "Deck board" : "Mesa de tarxetes",
    "%s on %s" : "%s n %s",
    "Action needed" : "Aición necesaria",
    "copy" : "copia",
    "To do" : "Xera pendiente",
    "Done" : "Fecho",
    "Example Task 3" : "Xera d'exemplu 3",
    "Example Task 2" : "Xera d'exemplu 2",
    "Example Task 1" : "Xera d'exemplu 1",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu supera la direutiva «upload_max_filesize» del ficheru php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu supera la direutiva «MAX_FILE_SIZE» que s'especificó nel formulariu HTML",
    "No file was uploaded" : "Nun se xubió nengún ficheru",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "Nun se pudo escribir el ficheru nel discu",
    "A PHP extension stopped the file upload" : "Una estensión PHP paró la xuba de ficheros",
    "No file uploaded or file size exceeds maximum of %s" : "Nun se xubió nengún ficheru o'l tamañu del ficheru supera'l máximu de %s",
    "Invalid date, date format must be YYYY-MM-DD" : "La data ye inválida, el so formatu ha ser AAAA-MM-DD",
    "Move card" : "Mover la tarxeta",
    "Cancel" : "Encaboxar",
    "File already exists" : "El ficheru yá esiste",
    "Drop your files to upload" : "Suelta los ficheros pa xubilos",
    "Add card" : "Amestar una tarxeta",
    "Archived cards" : "Tarxetes archivaes",
    "Add list" : "Amestar una llista",
    "List name" : "Nome de la llista",
    "Open" : "Abrir",
    "Completed" : "Completáu",
    "Next 24 hours" : "Les próximes 24 hores",
    "Next 7 days" : "Los próximos 7 díes",
    "Next 30 days" : "Los próximos 30 díes",
    "Open details" : "Abrir los detalles",
    "Details" : "Detalles",
    "Sharing" : "Comparticiñon",
    "Tags" : "Etiquetes",
    "Deleted items" : "Elementos desaniciaos",
    "Activity" : "Actividá",
    "Deleted lists" : "Llistes desaniciaes",
    "Undo" : "Desfacer",
    "Deleted cards" : "Tarxetes desaniciaes",
    "(Group)" : "(Grupu)",
    "(Team)" : "(Equipu)",
    "Can edit" : "Pue editar",
    "Owner" : "Propietariu",
    "Delete" : "Desaniciar",
    "Transfer" : "Tresferir",
    "Edit list title" : "Editar el títulu de la llista",
    "Archive all cards" : "Archivar toles carpetes",
    "Unarchive all cards" : "Desarchivar toles tarxetes",
    "Delete list" : "Desaniciar la llista",
    "Archive all cards in this list" : "Archivar toles tarxetes d'esta llista",
    "Unarchive all cards in this list" : "Desarchivar toles tarxetes d'esta llista",
    "Add a new card" : "Amestar una tarxeta nueva",
    "Card name" : "Nome de la tarxeta",
    "List deleted" : "Desanicióse la llista",
    "Edit" : "Editar",
    "Add a new tag" : "Amestar una etiqueta nueva",
    "Members" : "Miembros",
    "Show in Files" : "Amosar en Ficheros",
    "Download" : "Baxar",
    "Invalid path selected" : "Seleicionóse un camín inválidu",
    "Comments" : "Comentarios",
    "Modified" : "Modificóse",
    "The title cannot be empty." : "El títulu nun pue tar baleru",
    "No comments yet. Begin the discussion!" : "Nun hai nengún comentariu. ¡Comienza'l discutiniu!",
    "Failed to load comments" : "Nun se puen cargar los comentarios",
    "Save" : "Guardar",
    "The comment cannot be empty." : "El comentariu nun pue tar baleru.",
    "In reply to" : "En rempuesta a",
    "Reply" : "Responder",
    "Update" : "Anovar",
    "Created:" : "Creóse'l",
    "Description" : "Descripción",
    "(Unsaved)" : "(ensin guardar)",
    "(Saving…)" : "(Guardando…)",
    "Formatting help" : "Ayuda del formatu",
    "Edit description" : "Editar la descripción",
    "View description" : "Ver la descripción",
    "Mark as done" : "Marcar como fecha",
    "Archive card" : "Archivar la tarxeta",
    "(group)" : "(grupu)",
    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
    "Delete card" : "Desaniciar la tarxeta",
    "seconds ago" : "hai segundos",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Keyboard shortcut" : "Atayos del tecláu",
    "Action" : "Aición",
    "Ctrl" : "Ctrl",
    "Search" : "Guetar",
    "Shared with you" : "Compartióse contigo",
    "Cancel edit" : "Anular la edición",
    "All cards" : "Toles tarxetes",
    "No notifications" : "Nun hai nengún avisu",
    "No reminder" : "Nun hai nengún recordatoriu",
    "An error occurred" : "Prodúxose un error",
    "Today" : "Güei",
    "Tomorrow" : "Mañana",
    "No results found" : "Nun s'atopó nengún resultáu",
    "Close" : "Zarrar",
    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "Message from {author} in {conversationName}" : "Mensaxe de {author} en {conversationName}",
    "Error creating the share" : "Hebo un error al crear la compartición",
    "Share" : "Compartir"
},
"nplurals=2; plural=(n != 1);");
